@@ -1,6 +1,7 @@
 import requests
 import gzip
 import shutil
+import threading
 
 from typing import Literal
 from pathlib import Path
@@ -45,20 +46,18 @@ def wkhtmltopdf_bin(
 
     r = requests.get(url, stream=True)
 
-    with open(gz_path, "wb") as f:
-        for chunk in r.iter_content(chunk_size=1024):
-            if chunk:
-                f.write(chunk)
+    with threading.Lock():
+        with open(gz_path, "wb") as f:
+            for chunk in r.iter_content(chunk_size=1024):
+                if chunk:
+                    f.write(chunk)
 
-    if not gz_path.is_file():
-        print("==============================")
-        return
+        with gzip.open(gz_path, "rb") as f_in:
+            with open(bin_path, "wb") as f_out:
+                shutil.copyfileobj(f_in, f_out)
 
-    with gzip.open(gz_path, "rb") as f_in:
-        with open(bin_path, "wb") as f_out:
-            shutil.copyfileobj(f_in, f_out)
+        gz_path.unlink()
 
-    gz_path.unlink()
     return str(bin_path)
 
 
